@@ -13,7 +13,7 @@ use warnings;
 # When called with the "clean" argument it removes debian/package.filename files
 
 
-my %descriptions = 
+my %descriptions =
 (
 'ibritish'         => 'British English',
 'ibritish-small'   => 'British English - small',
@@ -38,12 +38,6 @@ my %suffixes =
     'insane'    => 'xxl+'
 );
 
-my %locales =
-(
-    'british'  => 'en_GB',
-    'american' => 'en_US'
-);
-
 
 
 die "Usage: $0 clean | generate\n" if $#ARGV != 0;
@@ -59,7 +53,7 @@ chdir "$debdirs[0]/.." or die "Cannot chdir to $debdirs[0]/..: $!\n";
 
 my $dir="debian/packages.d";
 
-# Don't use dh_listpackaes to make sure files for all packages are
+# Don't use dh_listpackages to make sure files for all packages are
 # always generated, even if we build binary-arch or -indep only.
 open CTRL, '<', "debian/control" or die "Cannot open debian/control: $!\n";
 my @packages=grep { s/^Package:\s*// } <CTRL>;
@@ -67,11 +61,11 @@ close CTRL;
 while (@packages)
 {
     chomp (my $package = shift(@packages));
-    my ($locale, $dictionary, $description, $munchlist);
+    my ($dictionary, $description, $munchlist);
     if (exists $descriptions{$package} && $package =~ /^i(([^-]+)-?([^-]+)?)$/)
     {
-        ($locale, $dictionary, $description, $munchlist) 
-         = ($locales{$2}, $1, $descriptions{$package}, $2.'.'.$suffixes{$3 ? $3 :''}); 
+        ($dictionary, $description, $munchlist)
+         = ($1, $descriptions{$package}, $2.'.'.$suffixes{$3 ? $3 :''});
     }
 
     my $master_file = $description ? "$dir/dictionaries.in" : "$dir/$package.in";
@@ -90,7 +84,7 @@ while (@packages)
             if ($2)
             {
                 next unless grep { $_ eq $package } split(' ', $2);
-            }    
+            }
 
             print " $file";
             unlink $file or die "Cannot unlink $file: $!\n" if -e $file;
@@ -98,7 +92,8 @@ while (@packages)
 
             open $fh, ">", $file or die "Cannot open $file for writing: $!\n";
             chmod 0444, $file or die "Cannot chmod $file: $!\n";
-            print $fh "### Generated from $master_file for $package ###\n" unless $file =~ /(info-ispell|inst|rm)$/;
+            print $fh "### Generated from $master_file for $package ###\n"
+                unless $file =~ /(info-ispell|lintian-overrides|inst|rm)$/;
         }
         elsif ($fh && !$cleanonly)
         {
@@ -108,7 +103,6 @@ while (@packages)
                 s/#DICTIONARY#/$dictionary/g   ;
                 s/#DESCRIPTION#/$description/g ;
                 s/#MUNCHLIST#/$munchlist/g     ;
-                s/#LOCALE#/$locale/g           ;
             }
             print $fh $_;
         }
